@@ -893,6 +893,10 @@ class FloatArrayWidget(AbstractDataSetWidget):
         self.arr = None  # le tableau si il a été modifié
         self.instance = None
 
+        self.dtype_line, self.dtype_label = get_image_layout("dtype.png", "")
+        self.first_line.insertSpacing(2, 5)
+        self.first_line.insertLayout(3, self.dtype_line)
+
     def edit_array(self):
         """Open an array editor dialog"""
         parent = self.parent_layout.parent
@@ -919,28 +923,31 @@ class FloatArrayWidget(AbstractDataSetWidget):
 
         format = self.item.get_prop_value("display", "format")
         minmax = self.item.get_prop_value("display", "minmax")
+        real_arr = numpy.real(arr)
         try:
             if minmax == "all":
-                mint = format % arr.min()
-                maxt = format % arr.max()
+                mint = format % real_arr.min()
+                maxt = format % real_arr.max()
             elif minmax == "columns":
                 mint = ", ".join(
-                    [format % arr[r, :].min() for r in range(arr.shape[0])]
+                    [format % real_arr[r, :].min() for r in range(arr.shape[0])]
                 )
                 maxt = ", ".join(
-                    [format % arr[r, :].max() for r in range(arr.shape[0])]
+                    [format % real_arr[r, :].max() for r in range(arr.shape[0])]
                 )
             else:
                 mint = ", ".join(
-                    [format % arr[:, r].min() for r in range(arr.shape[1])]
+                    [format % real_arr[:, r].min() for r in range(arr.shape[1])]
                 )
                 maxt = ", ".join(
-                    [format % arr[:, r].max() for r in range(arr.shape[1])]
+                    [format % real_arr[:, r].max() for r in range(arr.shape[1])]
                 )
         except (TypeError, IndexError):
             mint, maxt = "-", "-"
         self.min_label.setText(mint)
         self.max_label.setText(maxt)
+        typestr = str(arr.dtype)
+        self.dtype_label.setText("-" if typestr == "object" else typestr)
 
     def set(self):
         """Override AbstractDataSetWidget method"""
